@@ -31,7 +31,6 @@
 #include <gdk/gdk.h>
 #include <cairo/cairo.h>
 #include <librsvg/rsvg.h>
-#include <librsvg/rsvg-cairo.h>
 #include <pango/pangocairo.h>
 
 void        xkb_cairo_draw_flag     (cairo_t *cr,
@@ -42,18 +41,19 @@ void        xkb_cairo_draw_flag     (cairo_t *cr,
                                      gint width,
                                      gint height,
                                      gint variant_markers_count,
+                                     gint textsize,
                                      GdkColor fgcolor);
 
 void        xkb_cairo_draw_label    (cairo_t *cr,
                                      const gchar *group_name,
-                                     gint panel_size,
-                                     gint actual_width,
-                                     gint actual_height,
-                                     gint width,
-                                     gint height,
-                                     gint variant_markers_count,
-                                     gint textsize,
-                                     GdkColor fgcolor);
+                                     const gint panel_size,
+                                     const gint actual_width,
+                                     const gint actual_height,
+                                     const gint width,
+                                     const gint height,
+                                     const gint variant_markers_count,
+                                     const gint textsize,
+                                     const GdkColor fgcolor);
 
 #endif
 
